# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from emby_client.api_client import ApiClient


class UserServiceApi(object):
    """NOTE: This class is auto generated.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def delete_users_by_id(self, id, **kwargs):  # noqa: E501
        """Deletes a user  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_users_by_id(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_users_by_id_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_users_by_id_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def delete_users_by_id_with_http_info(self, id, **kwargs):  # noqa: E501
        """Deletes a user  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_users_by_id_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_users_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `delete_users_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Users/{Id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_users_by_id_trackselections_by_tracktype(self, id, track_type, **kwargs):  # noqa: E501
        """Clears audio or subtitle track selections for a user  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_users_by_id_trackselections_by_tracktype(id, track_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str track_type: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_users_by_id_trackselections_by_tracktype_with_http_info(id, track_type, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_users_by_id_trackselections_by_tracktype_with_http_info(id, track_type, **kwargs)  # noqa: E501
            return data

    def delete_users_by_id_trackselections_by_tracktype_with_http_info(self, id, track_type, **kwargs):  # noqa: E501
        """Clears audio or subtitle track selections for a user  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_users_by_id_trackselections_by_tracktype_with_http_info(id, track_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str track_type: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'track_type']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_users_by_id_trackselections_by_tracktype" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `delete_users_by_id_trackselections_by_tracktype`")  # noqa: E501
        # verify the required parameter 'track_type' is set
        if ('track_type' not in params or
                params['track_type'] is None):
            raise ValueError("Missing the required parameter `track_type` when calling `delete_users_by_id_trackselections_by_tracktype`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501
        if 'track_type' in params:
            path_params['TrackType'] = params['track_type']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Users/{Id}/TrackSelections/{TrackType}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_users_by_id(self, id, **kwargs):  # noqa: E501
        """Gets a user by Id  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_users_by_id(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: UserDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_users_by_id_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_users_by_id_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_users_by_id_with_http_info(self, id, **kwargs):  # noqa: E501
        """Gets a user by Id  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_users_by_id_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: UserDto
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_users_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_users_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Users/{Id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_users_by_userid_typedsettings_by_key(self, key, user_id, **kwargs):  # noqa: E501
        """Gets a typed user setting  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_users_by_userid_typedsettings_by_key(key, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str key: Key (required)
        :param str user_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_users_by_userid_typedsettings_by_key_with_http_info(key, user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_users_by_userid_typedsettings_by_key_with_http_info(key, user_id, **kwargs)  # noqa: E501
            return data

    def get_users_by_userid_typedsettings_by_key_with_http_info(self, key, user_id, **kwargs):  # noqa: E501
        """Gets a typed user setting  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_users_by_userid_typedsettings_by_key_with_http_info(key, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str key: Key (required)
        :param str user_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['key', 'user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_users_by_userid_typedsettings_by_key" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'key' is set
        if ('key' not in params or
                params['key'] is None):
            raise ValueError("Missing the required parameter `key` when calling `get_users_by_userid_typedsettings_by_key`")  # noqa: E501
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `get_users_by_userid_typedsettings_by_key`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'key' in params:
            path_params['Key'] = params['key']  # noqa: E501
        if 'user_id' in params:
            path_params['UserId'] = params['user_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Users/{UserId}/TypedSettings/{Key}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_users_itemaccess(self, **kwargs):  # noqa: E501
        """Gets a list of users  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_users_itemaccess(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param bool is_hidden: Optional filter by IsHidden=true or false
        :param bool is_disabled: Optional filter by IsDisabled=true or false
        :param int start_index: Optional. The record index to start at. All items with a lower index will be dropped from the results.
        :param int limit: Optional. The maximum number of records to return
        :param str name_starts_with_or_greater: Optional filter by items whose name is sorted equally or greater than a given input string.
        :param str sort_order: Sort Order - Ascending,Descending
        :return: QueryResultUserDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_users_itemaccess_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_users_itemaccess_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_users_itemaccess_with_http_info(self, **kwargs):  # noqa: E501
        """Gets a list of users  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_users_itemaccess_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param bool is_hidden: Optional filter by IsHidden=true or false
        :param bool is_disabled: Optional filter by IsDisabled=true or false
        :param int start_index: Optional. The record index to start at. All items with a lower index will be dropped from the results.
        :param int limit: Optional. The maximum number of records to return
        :param str name_starts_with_or_greater: Optional filter by items whose name is sorted equally or greater than a given input string.
        :param str sort_order: Sort Order - Ascending,Descending
        :return: QueryResultUserDto
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['is_hidden', 'is_disabled', 'start_index', 'limit', 'name_starts_with_or_greater', 'sort_order']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_users_itemaccess" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'is_hidden' in params:
            query_params.append(('IsHidden', params['is_hidden']))  # noqa: E501
        if 'is_disabled' in params:
            query_params.append(('IsDisabled', params['is_disabled']))  # noqa: E501
        if 'start_index' in params:
            query_params.append(('StartIndex', params['start_index']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('Limit', params['limit']))  # noqa: E501
        if 'name_starts_with_or_greater' in params:
            query_params.append(('NameStartsWithOrGreater', params['name_starts_with_or_greater']))  # noqa: E501
        if 'sort_order' in params:
            query_params.append(('SortOrder', params['sort_order']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Users/ItemAccess', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='QueryResultUserDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_users_prefixes(self, **kwargs):  # noqa: E501
        """Gets a list of users  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_users_prefixes(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param bool is_hidden: Optional filter by IsHidden=true or false
        :param bool is_disabled: Optional filter by IsDisabled=true or false
        :param int start_index: Optional. The record index to start at. All items with a lower index will be dropped from the results.
        :param int limit: Optional. The maximum number of records to return
        :param str name_starts_with_or_greater: Optional filter by items whose name is sorted equally or greater than a given input string.
        :param str sort_order: Sort Order - Ascending,Descending
        :return: list[NameIdPair]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_users_prefixes_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_users_prefixes_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_users_prefixes_with_http_info(self, **kwargs):  # noqa: E501
        """Gets a list of users  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_users_prefixes_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param bool is_hidden: Optional filter by IsHidden=true or false
        :param bool is_disabled: Optional filter by IsDisabled=true or false
        :param int start_index: Optional. The record index to start at. All items with a lower index will be dropped from the results.
        :param int limit: Optional. The maximum number of records to return
        :param str name_starts_with_or_greater: Optional filter by items whose name is sorted equally or greater than a given input string.
        :param str sort_order: Sort Order - Ascending,Descending
        :return: list[NameIdPair]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['is_hidden', 'is_disabled', 'start_index', 'limit', 'name_starts_with_or_greater', 'sort_order']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_users_prefixes" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'is_hidden' in params:
            query_params.append(('IsHidden', params['is_hidden']))  # noqa: E501
        if 'is_disabled' in params:
            query_params.append(('IsDisabled', params['is_disabled']))  # noqa: E501
        if 'start_index' in params:
            query_params.append(('StartIndex', params['start_index']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('Limit', params['limit']))  # noqa: E501
        if 'name_starts_with_or_greater' in params:
            query_params.append(('NameStartsWithOrGreater', params['name_starts_with_or_greater']))  # noqa: E501
        if 'sort_order' in params:
            query_params.append(('SortOrder', params['sort_order']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Users/Prefixes', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[NameIdPair]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_users_public(self, **kwargs):  # noqa: E501
        """Gets a list of publicly visible users for display on a login screen.  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_users_public(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[UserDto]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_users_public_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_users_public_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_users_public_with_http_info(self, **kwargs):  # noqa: E501
        """Gets a list of publicly visible users for display on a login screen.  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_users_public_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[UserDto]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_users_public" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Users/Public', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[UserDto]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_users_query(self, **kwargs):  # noqa: E501
        """Gets a list of users  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_users_query(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param bool is_hidden: Optional filter by IsHidden=true or false
        :param bool is_disabled: Optional filter by IsDisabled=true or false
        :param int start_index: Optional. The record index to start at. All items with a lower index will be dropped from the results.
        :param int limit: Optional. The maximum number of records to return
        :param str name_starts_with_or_greater: Optional filter by items whose name is sorted equally or greater than a given input string.
        :param str sort_order: Sort Order - Ascending,Descending
        :return: QueryResultUserDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_users_query_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_users_query_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_users_query_with_http_info(self, **kwargs):  # noqa: E501
        """Gets a list of users  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_users_query_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param bool is_hidden: Optional filter by IsHidden=true or false
        :param bool is_disabled: Optional filter by IsDisabled=true or false
        :param int start_index: Optional. The record index to start at. All items with a lower index will be dropped from the results.
        :param int limit: Optional. The maximum number of records to return
        :param str name_starts_with_or_greater: Optional filter by items whose name is sorted equally or greater than a given input string.
        :param str sort_order: Sort Order - Ascending,Descending
        :return: QueryResultUserDto
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['is_hidden', 'is_disabled', 'start_index', 'limit', 'name_starts_with_or_greater', 'sort_order']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_users_query" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'is_hidden' in params:
            query_params.append(('IsHidden', params['is_hidden']))  # noqa: E501
        if 'is_disabled' in params:
            query_params.append(('IsDisabled', params['is_disabled']))  # noqa: E501
        if 'start_index' in params:
            query_params.append(('StartIndex', params['start_index']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('Limit', params['limit']))  # noqa: E501
        if 'name_starts_with_or_greater' in params:
            query_params.append(('NameStartsWithOrGreater', params['name_starts_with_or_greater']))  # noqa: E501
        if 'sort_order' in params:
            query_params.append(('SortOrder', params['sort_order']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Users/Query', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='QueryResultUserDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_users_authenticatebyname(self, body, x_emby_authorization, **kwargs):  # noqa: E501
        """Authenticates a user  # noqa: E501

        Authenticate a user by nane and password. A 200 status code indicates success, while anything in the 400 or 500 range indicates failure --- Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_users_authenticatebyname(body, x_emby_authorization, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AuthenticateUserByName body: AuthenticateUserByName (required)
        :param str x_emby_authorization: The authorization header can be either named 'Authorization' or 'X-Emby-Authorization'.    It must be of the following schema:     Emby UserId=\"(guid)\", Client=\"(string)\", Device=\"(string)\", DeviceId=\"(string)\", Version=\"string\", Token=\"(string)\"     Please consult the documentation for further details. (required)
        :return: AuthenticationAuthenticationResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_users_authenticatebyname_with_http_info(body, x_emby_authorization, **kwargs)  # noqa: E501
        else:
            (data) = self.post_users_authenticatebyname_with_http_info(body, x_emby_authorization, **kwargs)  # noqa: E501
            return data

    def post_users_authenticatebyname_with_http_info(self, body, x_emby_authorization, **kwargs):  # noqa: E501
        """Authenticates a user  # noqa: E501

        Authenticate a user by nane and password. A 200 status code indicates success, while anything in the 400 or 500 range indicates failure --- Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_users_authenticatebyname_with_http_info(body, x_emby_authorization, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AuthenticateUserByName body: AuthenticateUserByName (required)
        :param str x_emby_authorization: The authorization header can be either named 'Authorization' or 'X-Emby-Authorization'.    It must be of the following schema:     Emby UserId=\"(guid)\", Client=\"(string)\", Device=\"(string)\", DeviceId=\"(string)\", Version=\"string\", Token=\"(string)\"     Please consult the documentation for further details. (required)
        :return: AuthenticationAuthenticationResult
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'x_emby_authorization']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_users_authenticatebyname" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_users_authenticatebyname`")  # noqa: E501
        # verify the required parameter 'x_emby_authorization' is set
        if ('x_emby_authorization' not in params or
                params['x_emby_authorization'] is None):
            raise ValueError("Missing the required parameter `x_emby_authorization` when calling `post_users_authenticatebyname`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_emby_authorization' in params:
            header_params['X-Emby-Authorization'] = params['x_emby_authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Users/AuthenticateByName', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AuthenticationAuthenticationResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_users_by_id(self, body, id, **kwargs):  # noqa: E501
        """Updates a user  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_users_by_id(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserDto body: UserDto:  (required)
        :param str id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_users_by_id_with_http_info(body, id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_users_by_id_with_http_info(body, id, **kwargs)  # noqa: E501
            return data

    def post_users_by_id_with_http_info(self, body, id, **kwargs):  # noqa: E501
        """Updates a user  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_users_by_id_with_http_info(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserDto body: UserDto:  (required)
        :param str id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_users_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_users_by_id`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `post_users_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Users/{Id}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_users_by_id_authenticate(self, body, id, **kwargs):  # noqa: E501
        """Authenticates a user  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_users_by_id_authenticate(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AuthenticateUser body: AuthenticateUser (required)
        :param str id: (required)
        :return: AuthenticationAuthenticationResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_users_by_id_authenticate_with_http_info(body, id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_users_by_id_authenticate_with_http_info(body, id, **kwargs)  # noqa: E501
            return data

    def post_users_by_id_authenticate_with_http_info(self, body, id, **kwargs):  # noqa: E501
        """Authenticates a user  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_users_by_id_authenticate_with_http_info(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AuthenticateUser body: AuthenticateUser (required)
        :param str id: (required)
        :return: AuthenticationAuthenticationResult
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_users_by_id_authenticate" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_users_by_id_authenticate`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `post_users_by_id_authenticate`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Users/{Id}/Authenticate', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AuthenticationAuthenticationResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_users_by_id_configuration(self, body, id, **kwargs):  # noqa: E501
        """Updates a user configuration  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_users_by_id_configuration(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserConfiguration body: UserConfiguration:  (required)
        :param str id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_users_by_id_configuration_with_http_info(body, id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_users_by_id_configuration_with_http_info(body, id, **kwargs)  # noqa: E501
            return data

    def post_users_by_id_configuration_with_http_info(self, body, id, **kwargs):  # noqa: E501
        """Updates a user configuration  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_users_by_id_configuration_with_http_info(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserConfiguration body: UserConfiguration:  (required)
        :param str id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_users_by_id_configuration" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_users_by_id_configuration`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `post_users_by_id_configuration`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Users/{Id}/Configuration', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_users_by_id_configuration_partial(self, body, id, **kwargs):  # noqa: E501
        """Updates a user configuration  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_users_by_id_configuration_partial(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Object body: Binary stream (required)
        :param str id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_users_by_id_configuration_partial_with_http_info(body, id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_users_by_id_configuration_partial_with_http_info(body, id, **kwargs)  # noqa: E501
            return data

    def post_users_by_id_configuration_partial_with_http_info(self, body, id, **kwargs):  # noqa: E501
        """Updates a user configuration  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_users_by_id_configuration_partial_with_http_info(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Object body: Binary stream (required)
        :param str id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_users_by_id_configuration_partial" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_users_by_id_configuration_partial`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `post_users_by_id_configuration_partial`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/octet-stream'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Users/{Id}/Configuration/Partial', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_users_by_id_delete(self, id, **kwargs):  # noqa: E501
        """Deletes a user  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_users_by_id_delete(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_users_by_id_delete_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_users_by_id_delete_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def post_users_by_id_delete_with_http_info(self, id, **kwargs):  # noqa: E501
        """Deletes a user  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_users_by_id_delete_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_users_by_id_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `post_users_by_id_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Users/{Id}/Delete', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_users_by_id_password(self, body, id, **kwargs):  # noqa: E501
        """Updates a user's password  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_users_by_id_password(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateUserPassword body: UpdateUserPassword (required)
        :param str id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_users_by_id_password_with_http_info(body, id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_users_by_id_password_with_http_info(body, id, **kwargs)  # noqa: E501
            return data

    def post_users_by_id_password_with_http_info(self, body, id, **kwargs):  # noqa: E501
        """Updates a user's password  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_users_by_id_password_with_http_info(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateUserPassword body: UpdateUserPassword (required)
        :param str id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_users_by_id_password" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_users_by_id_password`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `post_users_by_id_password`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Users/{Id}/Password', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_users_by_id_policy(self, body, id, **kwargs):  # noqa: E501
        """Updates a user policy  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_users_by_id_policy(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserPolicy body: UserPolicy:  (required)
        :param str id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_users_by_id_policy_with_http_info(body, id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_users_by_id_policy_with_http_info(body, id, **kwargs)  # noqa: E501
            return data

    def post_users_by_id_policy_with_http_info(self, body, id, **kwargs):  # noqa: E501
        """Updates a user policy  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_users_by_id_policy_with_http_info(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserPolicy body: UserPolicy:  (required)
        :param str id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_users_by_id_policy" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_users_by_id_policy`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `post_users_by_id_policy`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Users/{Id}/Policy', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_users_by_id_trackselections_by_tracktype_delete(self, id, track_type, **kwargs):  # noqa: E501
        """Clears audio or subtitle track selections for a user  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_users_by_id_trackselections_by_tracktype_delete(id, track_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str track_type: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_users_by_id_trackselections_by_tracktype_delete_with_http_info(id, track_type, **kwargs)  # noqa: E501
        else:
            (data) = self.post_users_by_id_trackselections_by_tracktype_delete_with_http_info(id, track_type, **kwargs)  # noqa: E501
            return data

    def post_users_by_id_trackselections_by_tracktype_delete_with_http_info(self, id, track_type, **kwargs):  # noqa: E501
        """Clears audio or subtitle track selections for a user  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_users_by_id_trackselections_by_tracktype_delete_with_http_info(id, track_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str track_type: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'track_type']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_users_by_id_trackselections_by_tracktype_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `post_users_by_id_trackselections_by_tracktype_delete`")  # noqa: E501
        # verify the required parameter 'track_type' is set
        if ('track_type' not in params or
                params['track_type'] is None):
            raise ValueError("Missing the required parameter `track_type` when calling `post_users_by_id_trackselections_by_tracktype_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501
        if 'track_type' in params:
            path_params['TrackType'] = params['track_type']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Users/{Id}/TrackSelections/{TrackType}/Delete', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_users_by_userid_typedsettings_by_key(self, body, user_id, key, **kwargs):  # noqa: E501
        """Updates a typed user setting  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_users_by_userid_typedsettings_by_key(body, user_id, key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Object body: Binary stream (required)
        :param str user_id: (required)
        :param str key: Key (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_users_by_userid_typedsettings_by_key_with_http_info(body, user_id, key, **kwargs)  # noqa: E501
        else:
            (data) = self.post_users_by_userid_typedsettings_by_key_with_http_info(body, user_id, key, **kwargs)  # noqa: E501
            return data

    def post_users_by_userid_typedsettings_by_key_with_http_info(self, body, user_id, key, **kwargs):  # noqa: E501
        """Updates a typed user setting  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_users_by_userid_typedsettings_by_key_with_http_info(body, user_id, key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Object body: Binary stream (required)
        :param str user_id: (required)
        :param str key: Key (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'user_id', 'key']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_users_by_userid_typedsettings_by_key" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_users_by_userid_typedsettings_by_key`")  # noqa: E501
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `post_users_by_userid_typedsettings_by_key`")  # noqa: E501
        # verify the required parameter 'key' is set
        if ('key' not in params or
                params['key'] is None):
            raise ValueError("Missing the required parameter `key` when calling `post_users_by_userid_typedsettings_by_key`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['UserId'] = params['user_id']  # noqa: E501
        if 'key' in params:
            path_params['Key'] = params['key']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/octet-stream'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Users/{UserId}/TypedSettings/{Key}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_users_forgotpassword(self, body, **kwargs):  # noqa: E501
        """Initiates the forgot password process for a local user  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_users_forgotpassword(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ForgotPassword body: ForgotPassword (required)
        :return: ForgotPasswordResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_users_forgotpassword_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.post_users_forgotpassword_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def post_users_forgotpassword_with_http_info(self, body, **kwargs):  # noqa: E501
        """Initiates the forgot password process for a local user  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_users_forgotpassword_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ForgotPassword body: ForgotPassword (required)
        :return: ForgotPasswordResult
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_users_forgotpassword" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_users_forgotpassword`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Users/ForgotPassword', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ForgotPasswordResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_users_forgotpassword_pin(self, body, **kwargs):  # noqa: E501
        """Redeems a forgot password pin  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_users_forgotpassword_pin(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ForgotPasswordPin body: ForgotPasswordPin (required)
        :return: PinRedeemResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_users_forgotpassword_pin_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.post_users_forgotpassword_pin_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def post_users_forgotpassword_pin_with_http_info(self, body, **kwargs):  # noqa: E501
        """Redeems a forgot password pin  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_users_forgotpassword_pin_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ForgotPasswordPin body: ForgotPasswordPin (required)
        :return: PinRedeemResult
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_users_forgotpassword_pin" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_users_forgotpassword_pin`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Users/ForgotPassword/Pin', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PinRedeemResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_users_new(self, body, **kwargs):  # noqa: E501
        """Creates a user  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_users_new(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateUserByName body: CreateUserByName (required)
        :return: UserDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_users_new_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.post_users_new_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def post_users_new_with_http_info(self, body, **kwargs):  # noqa: E501
        """Creates a user  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_users_new_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateUserByName body: CreateUserByName (required)
        :return: UserDto
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_users_new" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_users_new`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Users/New', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class SyncDialogOptions(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'targets': 'list[SyncTarget]',
        'options': 'list[SyncJobOption]',
        'quality_options': 'list[SyncQualityOption]',
        'profile_options': 'list[SyncProfileOption]'
    }

    attribute_map = {
        'targets': 'Targets',
        'options': 'Options',
        'quality_options': 'QualityOptions',
        'profile_options': 'ProfileOptions'
    }

    def __init__(self, targets=None, options=None, quality_options=None, profile_options=None):  # noqa: E501
        """SyncDialogOptions - a model defined in Swagger"""  # noqa: E501
        self._targets = None
        self._options = None
        self._quality_options = None
        self._profile_options = None
        self.discriminator = None
        if targets is not None:
            self.targets = targets
        if options is not None:
            self.options = options
        if quality_options is not None:
            self.quality_options = quality_options
        if profile_options is not None:
            self.profile_options = profile_options

    @property
    def targets(self):
        """Gets the targets of this SyncDialogOptions.  # noqa: E501


        :return: The targets of this SyncDialogOptions.  # noqa: E501
        :rtype: list[SyncTarget]
        """
        return self._targets

    @targets.setter
    def targets(self, targets):
        """Sets the targets of this SyncDialogOptions.


        :param targets: The targets of this SyncDialogOptions.  # noqa: E501
        :type: list[SyncTarget]
        """

        self._targets = targets

    @property
    def options(self):
        """Gets the options of this SyncDialogOptions.  # noqa: E501


        :return: The options of this SyncDialogOptions.  # noqa: E501
        :rtype: list[SyncJobOption]
        """
        return self._options

    @options.setter
    def options(self, options):
        """Sets the options of this SyncDialogOptions.


        :param options: The options of this SyncDialogOptions.  # noqa: E501
        :type: list[SyncJobOption]
        """

        self._options = options

    @property
    def quality_options(self):
        """Gets the quality_options of this SyncDialogOptions.  # noqa: E501


        :return: The quality_options of this SyncDialogOptions.  # noqa: E501
        :rtype: list[SyncQualityOption]
        """
        return self._quality_options

    @quality_options.setter
    def quality_options(self, quality_options):
        """Sets the quality_options of this SyncDialogOptions.


        :param quality_options: The quality_options of this SyncDialogOptions.  # noqa: E501
        :type: list[SyncQualityOption]
        """

        self._quality_options = quality_options

    @property
    def profile_options(self):
        """Gets the profile_options of this SyncDialogOptions.  # noqa: E501


        :return: The profile_options of this SyncDialogOptions.  # noqa: E501
        :rtype: list[SyncProfileOption]
        """
        return self._profile_options

    @profile_options.setter
    def profile_options(self, profile_options):
        """Sets the profile_options of this SyncDialogOptions.


        :param profile_options: The profile_options of this SyncDialogOptions.  # noqa: E501
        :type: list[SyncProfileOption]
        """

        self._profile_options = profile_options

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SyncDialogOptions, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SyncDialogOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class TaskResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'start_time_utc': 'datetime',
        'end_time_utc': 'datetime',
        'status': 'TaskCompletionStatus',
        'name': 'str',
        'key': 'str',
        'id': 'str',
        'error_message': 'str',
        'long_error_message': 'str'
    }

    attribute_map = {
        'start_time_utc': 'StartTimeUtc',
        'end_time_utc': 'EndTimeUtc',
        'status': 'Status',
        'name': 'Name',
        'key': 'Key',
        'id': 'Id',
        'error_message': 'ErrorMessage',
        'long_error_message': 'LongErrorMessage'
    }

    def __init__(self, start_time_utc=None, end_time_utc=None, status=None, name=None, key=None, id=None, error_message=None, long_error_message=None):  # noqa: E501
        """TaskResult - a model defined in Swagger"""  # noqa: E501
        self._start_time_utc = None
        self._end_time_utc = None
        self._status = None
        self._name = None
        self._key = None
        self._id = None
        self._error_message = None
        self._long_error_message = None
        self.discriminator = None
        if start_time_utc is not None:
            self.start_time_utc = start_time_utc
        if end_time_utc is not None:
            self.end_time_utc = end_time_utc
        if status is not None:
            self.status = status
        if name is not None:
            self.name = name
        if key is not None:
            self.key = key
        if id is not None:
            self.id = id
        if error_message is not None:
            self.error_message = error_message
        if long_error_message is not None:
            self.long_error_message = long_error_message

    @property
    def start_time_utc(self):
        """Gets the start_time_utc of this TaskResult.  # noqa: E501

        The start time UTC.  # noqa: E501

        :return: The start_time_utc of this TaskResult.  # noqa: E501
        :rtype: datetime
        """
        return self._start_time_utc

    @start_time_utc.setter
    def start_time_utc(self, start_time_utc):
        """Sets the start_time_utc of this TaskResult.

        The start time UTC.  # noqa: E501

        :param start_time_utc: The start_time_utc of this TaskResult.  # noqa: E501
        :type: datetime
        """

        self._start_time_utc = start_time_utc

    @property
    def end_time_utc(self):
        """Gets the end_time_utc of this TaskResult.  # noqa: E501

        The end time UTC.  # noqa: E501

        :return: The end_time_utc of this TaskResult.  # noqa: E501
        :rtype: datetime
        """
        return self._end_time_utc

    @end_time_utc.setter
    def end_time_utc(self, end_time_utc):
        """Sets the end_time_utc of this TaskResult.

        The end time UTC.  # noqa: E501

        :param end_time_utc: The end_time_utc of this TaskResult.  # noqa: E501
        :type: datetime
        """

        self._end_time_utc = end_time_utc

    @property
    def status(self):
        """Gets the status of this TaskResult.  # noqa: E501


        :return: The status of this TaskResult.  # noqa: E501
        :rtype: TaskCompletionStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this TaskResult.


        :param status: The status of this TaskResult.  # noqa: E501
        :type: TaskCompletionStatus
        """

        self._status = status

    @property
    def name(self):
        """Gets the name of this TaskResult.  # noqa: E501

        The name.  # noqa: E501

        :return: The name of this TaskResult.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TaskResult.

        The name.  # noqa: E501

        :param name: The name of this TaskResult.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def key(self):
        """Gets the key of this TaskResult.  # noqa: E501

        The key.  # noqa: E501

        :return: The key of this TaskResult.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this TaskResult.

        The key.  # noqa: E501

        :param key: The key of this TaskResult.  # noqa: E501
        :type: str
        """

        self._key = key

    @property
    def id(self):
        """Gets the id of this TaskResult.  # noqa: E501

        The id.  # noqa: E501

        :return: The id of this TaskResult.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this TaskResult.

        The id.  # noqa: E501

        :param id: The id of this TaskResult.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def error_message(self):
        """Gets the error_message of this TaskResult.  # noqa: E501

        The error message.  # noqa: E501

        :return: The error_message of this TaskResult.  # noqa: E501
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """Sets the error_message of this TaskResult.

        The error message.  # noqa: E501

        :param error_message: The error_message of this TaskResult.  # noqa: E501
        :type: str
        """

        self._error_message = error_message

    @property
    def long_error_message(self):
        """Gets the long_error_message of this TaskResult.  # noqa: E501

        The long error message.  # noqa: E501

        :return: The long_error_message of this TaskResult.  # noqa: E501
        :rtype: str
        """
        return self._long_error_message

    @long_error_message.setter
    def long_error_message(self, long_error_message):
        """Sets the long_error_message of this TaskResult.

        The long error message.  # noqa: E501

        :param long_error_message: The long_error_message of this TaskResult.  # noqa: E501
        :type: str
        """

        self._long_error_message = long_error_message

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TaskResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TaskResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class SessionSessionInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'play_state': 'PlayerStateInfo',
        'additional_users': 'list[SessionUserInfo]',
        'remote_end_point': 'str',
        'protocol': 'str',
        'playable_media_types': 'list[str]',
        'playlist_item_id': 'str',
        'playlist_index': 'int',
        'playlist_length': 'int',
        'id': 'str',
        'server_id': 'str',
        'user_id': 'str',
        'user_name': 'str',
        'user_primary_image_tag': 'str',
        'client': 'str',
        'last_activity_date': 'datetime',
        'device_name': 'str',
        'device_type': 'str',
        'now_playing_item': 'BaseItemDto',
        'internal_device_id': 'int',
        'device_id': 'str',
        'application_version': 'str',
        'app_icon_url': 'str',
        'supported_commands': 'list[str]',
        'transcoding_info': 'TranscodingInfo',
        'supports_remote_control': 'bool'
    }

    attribute_map = {
        'play_state': 'PlayState',
        'additional_users': 'AdditionalUsers',
        'remote_end_point': 'RemoteEndPoint',
        'protocol': 'Protocol',
        'playable_media_types': 'PlayableMediaTypes',
        'playlist_item_id': 'PlaylistItemId',
        'playlist_index': 'PlaylistIndex',
        'playlist_length': 'PlaylistLength',
        'id': 'Id',
        'server_id': 'ServerId',
        'user_id': 'UserId',
        'user_name': 'UserName',
        'user_primary_image_tag': 'UserPrimaryImageTag',
        'client': 'Client',
        'last_activity_date': 'LastActivityDate',
        'device_name': 'DeviceName',
        'device_type': 'DeviceType',
        'now_playing_item': 'NowPlayingItem',
        'internal_device_id': 'InternalDeviceId',
        'device_id': 'DeviceId',
        'application_version': 'ApplicationVersion',
        'app_icon_url': 'AppIconUrl',
        'supported_commands': 'SupportedCommands',
        'transcoding_info': 'TranscodingInfo',
        'supports_remote_control': 'SupportsRemoteControl'
    }

    def __init__(self, play_state=None, additional_users=None, remote_end_point=None, protocol=None, playable_media_types=None, playlist_item_id=None, playlist_index=None, playlist_length=None, id=None, server_id=None, user_id=None, user_name=None, user_primary_image_tag=None, client=None, last_activity_date=None, device_name=None, device_type=None, now_playing_item=None, internal_device_id=None, device_id=None, application_version=None, app_icon_url=None, supported_commands=None, transcoding_info=None, supports_remote_control=None):  # noqa: E501
        """SessionSessionInfo - a model defined in Swagger"""  # noqa: E501
        self._play_state = None
        self._additional_users = None
        self._remote_end_point = None
        self._protocol = None
        self._playable_media_types = None
        self._playlist_item_id = None
        self._playlist_index = None
        self._playlist_length = None
        self._id = None
        self._server_id = None
        self._user_id = None
        self._user_name = None
        self._user_primary_image_tag = None
        self._client = None
        self._last_activity_date = None
        self._device_name = None
        self._device_type = None
        self._now_playing_item = None
        self._internal_device_id = None
        self._device_id = None
        self._application_version = None
        self._app_icon_url = None
        self._supported_commands = None
        self._transcoding_info = None
        self._supports_remote_control = None
        self.discriminator = None
        if play_state is not None:
            self.play_state = play_state
        if additional_users is not None:
            self.additional_users = additional_users
        if remote_end_point is not None:
            self.remote_end_point = remote_end_point
        if protocol is not None:
            self.protocol = protocol
        if playable_media_types is not None:
            self.playable_media_types = playable_media_types
        if playlist_item_id is not None:
            self.playlist_item_id = playlist_item_id
        if playlist_index is not None:
            self.playlist_index = playlist_index
        if playlist_length is not None:
            self.playlist_length = playlist_length
        if id is not None:
            self.id = id
        if server_id is not None:
            self.server_id = server_id
        if user_id is not None:
            self.user_id = user_id
        if user_name is not None:
            self.user_name = user_name
        if user_primary_image_tag is not None:
            self.user_primary_image_tag = user_primary_image_tag
        if client is not None:
            self.client = client
        if last_activity_date is not None:
            self.last_activity_date = last_activity_date
        if device_name is not None:
            self.device_name = device_name
        if device_type is not None:
            self.device_type = device_type
        if now_playing_item is not None:
            self.now_playing_item = now_playing_item
        if internal_device_id is not None:
            self.internal_device_id = internal_device_id
        if device_id is not None:
            self.device_id = device_id
        if application_version is not None:
            self.application_version = application_version
        if app_icon_url is not None:
            self.app_icon_url = app_icon_url
        if supported_commands is not None:
            self.supported_commands = supported_commands
        if transcoding_info is not None:
            self.transcoding_info = transcoding_info
        if supports_remote_control is not None:
            self.supports_remote_control = supports_remote_control

    @property
    def play_state(self):
        """Gets the play_state of this SessionSessionInfo.  # noqa: E501


        :return: The play_state of this SessionSessionInfo.  # noqa: E501
        :rtype: PlayerStateInfo
        """
        return self._play_state

    @play_state.setter
    def play_state(self, play_state):
        """Sets the play_state of this SessionSessionInfo.


        :param play_state: The play_state of this SessionSessionInfo.  # noqa: E501
        :type: PlayerStateInfo
        """

        self._play_state = play_state

    @property
    def additional_users(self):
        """Gets the additional_users of this SessionSessionInfo.  # noqa: E501


        :return: The additional_users of this SessionSessionInfo.  # noqa: E501
        :rtype: list[SessionUserInfo]
        """
        return self._additional_users

    @additional_users.setter
    def additional_users(self, additional_users):
        """Sets the additional_users of this SessionSessionInfo.


        :param additional_users: The additional_users of this SessionSessionInfo.  # noqa: E501
        :type: list[SessionUserInfo]
        """

        self._additional_users = additional_users

    @property
    def remote_end_point(self):
        """Gets the remote_end_point of this SessionSessionInfo.  # noqa: E501

        The remote end point.  # noqa: E501

        :return: The remote_end_point of this SessionSessionInfo.  # noqa: E501
        :rtype: str
        """
        return self._remote_end_point

    @remote_end_point.setter
    def remote_end_point(self, remote_end_point):
        """Sets the remote_end_point of this SessionSessionInfo.

        The remote end point.  # noqa: E501

        :param remote_end_point: The remote_end_point of this SessionSessionInfo.  # noqa: E501
        :type: str
        """

        self._remote_end_point = remote_end_point

    @property
    def protocol(self):
        """Gets the protocol of this SessionSessionInfo.  # noqa: E501


        :return: The protocol of this SessionSessionInfo.  # noqa: E501
        :rtype: str
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """Sets the protocol of this SessionSessionInfo.


        :param protocol: The protocol of this SessionSessionInfo.  # noqa: E501
        :type: str
        """

        self._protocol = protocol

    @property
    def playable_media_types(self):
        """Gets the playable_media_types of this SessionSessionInfo.  # noqa: E501

        The playable media types.  # noqa: E501

        :return: The playable_media_types of this SessionSessionInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._playable_media_types

    @playable_media_types.setter
    def playable_media_types(self, playable_media_types):
        """Sets the playable_media_types of this SessionSessionInfo.

        The playable media types.  # noqa: E501

        :param playable_media_types: The playable_media_types of this SessionSessionInfo.  # noqa: E501
        :type: list[str]
        """

        self._playable_media_types = playable_media_types

    @property
    def playlist_item_id(self):
        """Gets the playlist_item_id of this SessionSessionInfo.  # noqa: E501


        :return: The playlist_item_id of this SessionSessionInfo.  # noqa: E501
        :rtype: str
        """
        return self._playlist_item_id

    @playlist_item_id.setter
    def playlist_item_id(self, playlist_item_id):
        """Sets the playlist_item_id of this SessionSessionInfo.


        :param playlist_item_id: The playlist_item_id of this SessionSessionInfo.  # noqa: E501
        :type: str
        """

        self._playlist_item_id = playlist_item_id

    @property
    def playlist_index(self):
        """Gets the playlist_index of this SessionSessionInfo.  # noqa: E501


        :return: The playlist_index of this SessionSessionInfo.  # noqa: E501
        :rtype: int
        """
        return self._playlist_index

    @playlist_index.setter
    def playlist_index(self, playlist_index):
        """Sets the playlist_index of this SessionSessionInfo.


        :param playlist_index: The playlist_index of this SessionSessionInfo.  # noqa: E501
        :type: int
        """

        self._playlist_index = playlist_index

    @property
    def playlist_length(self):
        """Gets the playlist_length of this SessionSessionInfo.  # noqa: E501


        :return: The playlist_length of this SessionSessionInfo.  # noqa: E501
        :rtype: int
        """
        return self._playlist_length

    @playlist_length.setter
    def playlist_length(self, playlist_length):
        """Sets the playlist_length of this SessionSessionInfo.


        :param playlist_length: The playlist_length of this SessionSessionInfo.  # noqa: E501
        :type: int
        """

        self._playlist_length = playlist_length

    @property
    def id(self):
        """Gets the id of this SessionSessionInfo.  # noqa: E501

        The id.  # noqa: E501

        :return: The id of this SessionSessionInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SessionSessionInfo.

        The id.  # noqa: E501

        :param id: The id of this SessionSessionInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def server_id(self):
        """Gets the server_id of this SessionSessionInfo.  # noqa: E501


        :return: The server_id of this SessionSessionInfo.  # noqa: E501
        :rtype: str
        """
        return self._server_id

    @server_id.setter
    def server_id(self, server_id):
        """Sets the server_id of this SessionSessionInfo.


        :param server_id: The server_id of this SessionSessionInfo.  # noqa: E501
        :type: str
        """

        self._server_id = server_id

    @property
    def user_id(self):
        """Gets the user_id of this SessionSessionInfo.  # noqa: E501

        The user id.  # noqa: E501

        :return: The user_id of this SessionSessionInfo.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this SessionSessionInfo.

        The user id.  # noqa: E501

        :param user_id: The user_id of this SessionSessionInfo.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def user_name(self):
        """Gets the user_name of this SessionSessionInfo.  # noqa: E501

        The username.  # noqa: E501

        :return: The user_name of this SessionSessionInfo.  # noqa: E501
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """Sets the user_name of this SessionSessionInfo.

        The username.  # noqa: E501

        :param user_name: The user_name of this SessionSessionInfo.  # noqa: E501
        :type: str
        """

        self._user_name = user_name

    @property
    def user_primary_image_tag(self):
        """Gets the user_primary_image_tag of this SessionSessionInfo.  # noqa: E501


        :return: The user_primary_image_tag of this SessionSessionInfo.  # noqa: E501
        :rtype: str
        """
        return self._user_primary_image_tag

    @user_primary_image_tag.setter
    def user_primary_image_tag(self, user_primary_image_tag):
        """Sets the user_primary_image_tag of this SessionSessionInfo.


        :param user_primary_image_tag: The user_primary_image_tag of this SessionSessionInfo.  # noqa: E501
        :type: str
        """

        self._user_primary_image_tag = user_primary_image_tag

    @property
    def client(self):
        """Gets the client of this SessionSessionInfo.  # noqa: E501

        The type of the client.  # noqa: E501

        :return: The client of this SessionSessionInfo.  # noqa: E501
        :rtype: str
        """
        return self._client

    @client.setter
    def client(self, client):
        """Sets the client of this SessionSessionInfo.

        The type of the client.  # noqa: E501

        :param client: The client of this SessionSessionInfo.  # noqa: E501
        :type: str
        """

        self._client = client

    @property
    def last_activity_date(self):
        """Gets the last_activity_date of this SessionSessionInfo.  # noqa: E501

        The last activity date.  # noqa: E501

        :return: The last_activity_date of this SessionSessionInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._last_activity_date

    @last_activity_date.setter
    def last_activity_date(self, last_activity_date):
        """Sets the last_activity_date of this SessionSessionInfo.

        The last activity date.  # noqa: E501

        :param last_activity_date: The last_activity_date of this SessionSessionInfo.  # noqa: E501
        :type: datetime
        """

        self._last_activity_date = last_activity_date

    @property
    def device_name(self):
        """Gets the device_name of this SessionSessionInfo.  # noqa: E501

        The name of the device.  # noqa: E501

        :return: The device_name of this SessionSessionInfo.  # noqa: E501
        :rtype: str
        """
        return self._device_name

    @device_name.setter
    def device_name(self, device_name):
        """Sets the device_name of this SessionSessionInfo.

        The name of the device.  # noqa: E501

        :param device_name: The device_name of this SessionSessionInfo.  # noqa: E501
        :type: str
        """

        self._device_name = device_name

    @property
    def device_type(self):
        """Gets the device_type of this SessionSessionInfo.  # noqa: E501


        :return: The device_type of this SessionSessionInfo.  # noqa: E501
        :rtype: str
        """
        return self._device_type

    @device_type.setter
    def device_type(self, device_type):
        """Sets the device_type of this SessionSessionInfo.


        :param device_type: The device_type of this SessionSessionInfo.  # noqa: E501
        :type: str
        """

        self._device_type = device_type

    @property
    def now_playing_item(self):
        """Gets the now_playing_item of this SessionSessionInfo.  # noqa: E501


        :return: The now_playing_item of this SessionSessionInfo.  # noqa: E501
        :rtype: BaseItemDto
        """
        return self._now_playing_item

    @now_playing_item.setter
    def now_playing_item(self, now_playing_item):
        """Sets the now_playing_item of this SessionSessionInfo.


        :param now_playing_item: The now_playing_item of this SessionSessionInfo.  # noqa: E501
        :type: BaseItemDto
        """

        self._now_playing_item = now_playing_item

    @property
    def internal_device_id(self):
        """Gets the internal_device_id of this SessionSessionInfo.  # noqa: E501


        :return: The internal_device_id of this SessionSessionInfo.  # noqa: E501
        :rtype: int
        """
        return self._internal_device_id

    @internal_device_id.setter
    def internal_device_id(self, internal_device_id):
        """Sets the internal_device_id of this SessionSessionInfo.


        :param internal_device_id: The internal_device_id of this SessionSessionInfo.  # noqa: E501
        :type: int
        """

        self._internal_device_id = internal_device_id

    @property
    def device_id(self):
        """Gets the device_id of this SessionSessionInfo.  # noqa: E501

        The device id.  # noqa: E501

        :return: The device_id of this SessionSessionInfo.  # noqa: E501
        :rtype: str
        """
        return self._device_id

    @device_id.setter
    def device_id(self, device_id):
        """Sets the device_id of this SessionSessionInfo.

        The device id.  # noqa: E501

        :param device_id: The device_id of this SessionSessionInfo.  # noqa: E501
        :type: str
        """

        self._device_id = device_id

    @property
    def application_version(self):
        """Gets the application_version of this SessionSessionInfo.  # noqa: E501

        The application version.  # noqa: E501

        :return: The application_version of this SessionSessionInfo.  # noqa: E501
        :rtype: str
        """
        return self._application_version

    @application_version.setter
    def application_version(self, application_version):
        """Sets the application_version of this SessionSessionInfo.

        The application version.  # noqa: E501

        :param application_version: The application_version of this SessionSessionInfo.  # noqa: E501
        :type: str
        """

        self._application_version = application_version

    @property
    def app_icon_url(self):
        """Gets the app_icon_url of this SessionSessionInfo.  # noqa: E501

        The application icon URL.  # noqa: E501

        :return: The app_icon_url of this SessionSessionInfo.  # noqa: E501
        :rtype: str
        """
        return self._app_icon_url

    @app_icon_url.setter
    def app_icon_url(self, app_icon_url):
        """Sets the app_icon_url of this SessionSessionInfo.

        The application icon URL.  # noqa: E501

        :param app_icon_url: The app_icon_url of this SessionSessionInfo.  # noqa: E501
        :type: str
        """

        self._app_icon_url = app_icon_url

    @property
    def supported_commands(self):
        """Gets the supported_commands of this SessionSessionInfo.  # noqa: E501

        The supported commands.  # noqa: E501

        :return: The supported_commands of this SessionSessionInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._supported_commands

    @supported_commands.setter
    def supported_commands(self, supported_commands):
        """Sets the supported_commands of this SessionSessionInfo.

        The supported commands.  # noqa: E501

        :param supported_commands: The supported_commands of this SessionSessionInfo.  # noqa: E501
        :type: list[str]
        """

        self._supported_commands = supported_commands

    @property
    def transcoding_info(self):
        """Gets the transcoding_info of this SessionSessionInfo.  # noqa: E501


        :return: The transcoding_info of this SessionSessionInfo.  # noqa: E501
        :rtype: TranscodingInfo
        """
        return self._transcoding_info

    @transcoding_info.setter
    def transcoding_info(self, transcoding_info):
        """Sets the transcoding_info of this SessionSessionInfo.


        :param transcoding_info: The transcoding_info of this SessionSessionInfo.  # noqa: E501
        :type: TranscodingInfo
        """

        self._transcoding_info = transcoding_info

    @property
    def supports_remote_control(self):
        """Gets the supports_remote_control of this SessionSessionInfo.  # noqa: E501


        :return: The supports_remote_control of this SessionSessionInfo.  # noqa: E501
        :rtype: bool
        """
        return self._supports_remote_control

    @supports_remote_control.setter
    def supports_remote_control(self, supports_remote_control):
        """Sets the supports_remote_control of this SessionSessionInfo.


        :param supports_remote_control: The supports_remote_control of this SessionSessionInfo.  # noqa: E501
        :type: bool
        """

        self._supports_remote_control = supports_remote_control

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SessionSessionInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SessionSessionInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class PluginsPluginInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'version': 'str',
        'configuration_file_name': 'str',
        'description': 'str',
        'id': 'str',
        'image_tag': 'str'
    }

    attribute_map = {
        'name': 'Name',
        'version': 'Version',
        'configuration_file_name': 'ConfigurationFileName',
        'description': 'Description',
        'id': 'Id',
        'image_tag': 'ImageTag'
    }

    def __init__(self, name=None, version=None, configuration_file_name=None, description=None, id=None, image_tag=None):  # noqa: E501
        """PluginsPluginInfo - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._version = None
        self._configuration_file_name = None
        self._description = None
        self._id = None
        self._image_tag = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if version is not None:
            self.version = version
        if configuration_file_name is not None:
            self.configuration_file_name = configuration_file_name
        if description is not None:
            self.description = description
        if id is not None:
            self.id = id
        if image_tag is not None:
            self.image_tag = image_tag

    @property
    def name(self):
        """Gets the name of this PluginsPluginInfo.  # noqa: E501

        The name.  # noqa: E501

        :return: The name of this PluginsPluginInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PluginsPluginInfo.

        The name.  # noqa: E501

        :param name: The name of this PluginsPluginInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def version(self):
        """Gets the version of this PluginsPluginInfo.  # noqa: E501

        The version.  # noqa: E501

        :return: The version of this PluginsPluginInfo.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this PluginsPluginInfo.

        The version.  # noqa: E501

        :param version: The version of this PluginsPluginInfo.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def configuration_file_name(self):
        """Gets the configuration_file_name of this PluginsPluginInfo.  # noqa: E501

        The name of the configuration file.  # noqa: E501

        :return: The configuration_file_name of this PluginsPluginInfo.  # noqa: E501
        :rtype: str
        """
        return self._configuration_file_name

    @configuration_file_name.setter
    def configuration_file_name(self, configuration_file_name):
        """Sets the configuration_file_name of this PluginsPluginInfo.

        The name of the configuration file.  # noqa: E501

        :param configuration_file_name: The configuration_file_name of this PluginsPluginInfo.  # noqa: E501
        :type: str
        """

        self._configuration_file_name = configuration_file_name

    @property
    def description(self):
        """Gets the description of this PluginsPluginInfo.  # noqa: E501

        The description.  # noqa: E501

        :return: The description of this PluginsPluginInfo.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this PluginsPluginInfo.

        The description.  # noqa: E501

        :param description: The description of this PluginsPluginInfo.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def id(self):
        """Gets the id of this PluginsPluginInfo.  # noqa: E501

        The unique id.  # noqa: E501

        :return: The id of this PluginsPluginInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PluginsPluginInfo.

        The unique id.  # noqa: E501

        :param id: The id of this PluginsPluginInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def image_tag(self):
        """Gets the image_tag of this PluginsPluginInfo.  # noqa: E501

        The image URL.  # noqa: E501

        :return: The image_tag of this PluginsPluginInfo.  # noqa: E501
        :rtype: str
        """
        return self._image_tag

    @image_tag.setter
    def image_tag(self, image_tag):
        """Sets the image_tag of this PluginsPluginInfo.

        The image URL.  # noqa: E501

        :param image_tag: The image_tag of this PluginsPluginInfo.  # noqa: E501
        :type: str
        """

        self._image_tag = image_tag

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PluginsPluginInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PluginsPluginInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
